@@ -58,7 +58,6 @@ import java.io.UnsupportedEncodingException;
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.UnknownHostException;
-import java.nio.charset.UnsupportedCharsetException;
 import java.security.PrivilegedActionException;
 import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
@@ -91,7 +90,6 @@ import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.notify.hostname.HostnameService;
-import com.openexchange.java.Charsets;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
 import com.openexchange.java.UnsynchronizedByteArrayInputStream;
@@ -110,6 +108,7 @@ import com.openexchange.mail.api.AuthenticationFailureHandlerResult.Type;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.config.MailProperties;
+import com.openexchange.mail.config.MailProxyConfig;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.SecuritySettings;
 import com.openexchange.mail.dataobjects.compose.ComposeType;
@@ -133,6 +132,7 @@ import com.openexchange.mailaccount.Account;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.TransportAuth;
+import com.openexchange.net.HostList;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.net.ssl.exception.SSLExceptionCode;
@@ -369,9 +369,16 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         {
             final String str = mimeMessage.getHeader("Disposition-Notification-To", null);
             if (!com.openexchange.java.Strings.isEmpty(str)) {
-                final InternetAddress[] addresses = QuotedInternetAddress.parse(str, false);
-                checkRecipients(addresses);
-                mimeMessage.setHeader("Disposition-Notification-To", addresses[0].toString());
+                if ("true".equalsIgnoreCase(str)) {
+                    Address[] fromAddresses = mimeMessage.getFrom();
+                    if (fromAddresses.length > 0 && fromAddresses[0] != null) {
+                        mimeMessage.setHeader("Disposition-Notification-To", fromAddresses[0].toString());
+                    }
+                } else {
+                    final InternetAddress[] addresses = QuotedInternetAddress.parse(str, false);
+                    checkRecipients(addresses);
+                    mimeMessage.setHeader("Disposition-Notification-To", addresses[0].toString());
+                }
             }
         }
     }
@@ -430,6 +437,16 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
             synchronized (this) {
                 if (null == smtpSession) {
                     final Properties smtpProps = SMTPSessionProperties.getDefaultSessionProperties();
+                    /*
+                     * Remove proxy settings for whitelisted hosts
+                     */
+                    HostList nonProxyHosts = MailProxyConfig.getInstance().getSmtpNonProxyHostList();
+                    if (nonProxyHosts.contains(smtpConfig.getSmtpServerAddress())) {
+                        smtpProps.remove("mail.smtp.proxy.host");
+                        smtpProps.remove("mail.smtp.proxy.port");
+                        smtpProps.remove("mail.smtps.proxy.host");
+                        smtpProps.remove("mail.smtps.proxy.port");
+                    }
                     smtpProps.put("mail.smtp.class", JavaSMTPTransport.class.getName());
                     smtpProps.put("com.openexchange.mail.maxMailSize", Long.toString(getMaxMailSize()));
 
@@ -700,16 +717,15 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         final String login = smtpConfig.getLogin();
         try {
             if (smtpConfig.getSMTPProperties().isSmtpAuth()) {
-                final String encodedPassword = authEncode(smtpConfig.getPassword());
-                final String encodedLogin = authEncode(login);
+                final String password = smtpConfig.getPassword();
                 if (isKerberosAuth()) {
                     try {
-                        Subject.doAs(kerberosSubject, new SaslSmtpLoginAction(transport, server, port, encodedLogin, encodedPassword));
+                        Subject.doAs(kerberosSubject, new SaslSmtpLoginAction(transport, server, port, login, password));
                     } catch (final PrivilegedActionException e) {
                         handlePrivilegedActionException(e);
                     }
                 } else {
-                    doConnectTransport(transport, server, port, null == encodedLogin ? "" : encodedLogin, null == encodedPassword ? "" : encodedPassword, smtpConfig, session);
+                    doConnectTransport(transport, server, port, null == login ? "" : login, null == password ? "" : password, smtpConfig, session);
                 }
             } else {
                 doConnectTransport(transport, server, port, null, null, smtpConfig, session);
@@ -1399,19 +1415,6 @@ abstract class AbstractSMTPTransport extends MailTransport implements MimeSuppor
         return userId;
     }
 
-    private String authEncode(final String s) throws OXException {
-        String tmp = s;
-        if (tmp != null) {
-            try {
-                tmp = new String(s.getBytes(Charsets.forName(getTransportConfig().getSMTPProperties().getSmtpAuthEnc())), Charsets.ISO_8859_1);
-            } catch (final UnsupportedCharsetException e) {
-                LOG.error("Unsupported encoding in a message detected and monitored", e);
-                mailInterfaceMonitor.addUnsupportedEncodingExceptions(e.getMessage());
-            }
-        }
-        return tmp;
-    }
-
     private void prepareAddresses(final Address[] addresses) {
         final int length = addresses.length;
         final StringBuilder tmp = new StringBuilder(32);
